### Variables

variable "environment" {
  description = "The short name of this deployed environment. For example: 'dev' or 'prod'. This short name will be used to name resources (CloudFront distributions, etc.)"
}

variable "artifact_bucket" {
  description = "The aws_s3_bucket object representing the artifact bucket where deployed artifacts, logs, etc. live."
}

variable "ecr_repo" {
  description = "ECR repository information."
}

variable "target_port" {
  description = "The port the deployed service will listen on."
}

variable "api_certificate_arn" {
  description = "ARN of the certificate to use for the API loadbalancer."
}

variable "cloudfront_certificate_arn" {
  description = "ARN of the certificate to use for CloudFront."
}

locals {
  environment_name  = "HffEntryForms-${var.environment}"
  app_domain_name   = "forms${var.environment == "prod" ? "" : "-${var.environment}"}.hopefamilyfellowship.com"
  api_domain_name   = "forms-api${var.environment == "prod" ? "" : "-${var.environment}"}.hopefamilyfellowship.com"
}

data "external" "git_describe" {
  program = ["sh", "-c", "git describe | xargs printf '{\"version\": \"%s\"}'"]
}

data "terraform_remote_state" "jdbsoft" {
  backend = "s3"

  config = {
    bucket = "operations.jdb-software.com"
    region = "us-west-2"
    key    = "terraform/operations.tfstate"
    dynamodb_table = "terraform-state-lock.jdb-software.com"
  }
}
